Changed the struct lxc_conf initialization function to the
right place.

Signed-off-by: Daniel Lezcano <daniel.lezcano@free.fr>
---
 src/lxc/conf.c        |   12 ++++++++++++
 src/lxc/conf.h        |    5 +++++
 src/lxc/config.c      |   12 ------------
 src/lxc/config.h      |    1 -
 src/lxc/lxc_create.c  |    2 +-
 src/lxc/lxc_execute.c |    2 +-
 6 files changed, 19 insertions(+), 15 deletions(-)

Index: lxc/src/lxc/conf.c
===================================================================
--- lxc.orig/src/lxc/conf.c
+++ lxc/src/lxc/conf.c
@@ -1300,6 +1300,18 @@ out:
 	return ret;
 }
 
+int lxc_conf_init(struct lxc_conf *conf)
+{
+	conf->rootfs = NULL;
+	conf->fstab = NULL;
+	conf->utsname = NULL;
+	conf->tty = 0;
+	conf->pts = 0;
+	lxc_list_init(&conf->cgroup);
+	lxc_list_init(&conf->networks);
+	return 0;
+}
+
 int lxc_configure(const char *name, struct lxc_conf *conf)
 {
 	if (!conf)
Index: lxc/src/lxc/conf.h
===================================================================
--- lxc.orig/src/lxc/conf.h
+++ lxc/src/lxc/conf.h
@@ -151,6 +151,11 @@ struct lxc_tty_info {
 };
 
 /*
+ * Initialize the lxc configuration structure
+ */
+extern int lxc_conf_init(struct lxc_conf *conf);
+
+/*
  * Configure the external resources for the container
  */
 extern int lxc_configure(const char *name, struct lxc_conf *conf);
Index: lxc/src/lxc/config.c
===================================================================
--- lxc.orig/src/lxc/config.c
+++ lxc/src/lxc/config.c
@@ -564,15 +564,3 @@ int lxc_config_read(const char *file, st
 	return lxc_file_for_each_line(file, parse_line, buffer,
 				      sizeof(buffer), conf);
 }
-
-int lxc_config_init(struct lxc_conf *conf)
-{
-	conf->rootfs = NULL;
-	conf->fstab = NULL;
-	conf->utsname = NULL;
-	conf->tty = 0;
-	conf->pts = 0;
-	lxc_list_init(&conf->cgroup);
-	lxc_list_init(&conf->networks);
-	return 0;
-}
Index: lxc/src/lxc/config.h
===================================================================
--- lxc.orig/src/lxc/config.h
+++ lxc/src/lxc/config.h
@@ -21,7 +21,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-extern int lxc_config_init(struct lxc_conf *conf);
 extern int lxc_config_read(const char *file, struct lxc_conf *conf);
 
 
Index: lxc/src/lxc/lxc_create.c
===================================================================
--- lxc.orig/src/lxc/lxc_create.c
+++ lxc/src/lxc/lxc_create.c
@@ -62,7 +62,7 @@ int main(int argc, char *argv[])
 	if (!name)
 		usage(argv[0]);
 
-	if (lxc_config_init(&lxc_conf)) {
+	if (lxc_conf_init(&lxc_conf)) {
 		fprintf(stderr, "failed to initialize the configuration\n");
 		return 1;
 	}
Index: lxc/src/lxc/lxc_execute.c
===================================================================
--- lxc.orig/src/lxc/lxc_execute.c
+++ lxc/src/lxc/lxc_execute.c
@@ -70,7 +70,7 @@ int main(int argc, char *argv[])
 
 	argc -= nbargs;
 	
-	if (lxc_config_init(&lxc_conf)) {
+	if (lxc_conf_init(&lxc_conf)) {
 		fprintf(stderr, "failed to initialize the configuration\n");
 		goto out;
 	}



